# GraphArray

GraphArray is a class of arrays defined on a network, which allows for 
fast computation and easy visualization.

When you plan to code some algorithms on networks, using GraphArray as the class
of control variables provide you easier debugging and summarization of the result
while keeping your calculation fast.

* [Documentation](https://geb-algebra.github.io/grapharray/)

